@@ -3,6 +3,8 @@ from aliyunsdkr_kvstore.request.v20150101.DescribeInstancesRequest import Descri
 from aliyunsdkr_kvstore.request.v20150101.DescribeDBInstanceNetInfoRequest import DescribeDBInstanceNetInfoRequest
 from aliyunsdkr_kvstore.request.v20150101.DescribeSecurityIpsRequest import DescribeSecurityIpsRequest
 from aliyunsdkr_kvstore.request.v20150101.DescribeInstanceAttributeRequest import DescribeInstanceAttributeRequest
+from aliyunsdkr_kvstore.request.v20150101.DescribeInstanceAutoRenewalAttributeRequest import \
+    DescribeInstanceAutoRenewalAttributeRequest
 
 
 class RKvstoreClient(AliCloudClient):
@@ -21,3 +23,5 @@ class RKvstoreClient(AliCloudClient):
     def describe_instance_attribute(self, query_params=None, body_params=None):
         return self.do_request(DescribeInstanceAttributeRequest, query_params, body_params)
 
+    def describe_instance_auto_renewal_attribute(self, query_params=None, body_params=None):
+        return self.do_request(DescribeInstanceAutoRenewalAttributeRequest, query_params, body_params)
